@@ -1,4 +1,4 @@
-# $Id: install.py 1089 2014-10-22 22:41:44Z mwall $
+# $Id: install.py 1187 2014-12-13 16:01:32Z mwall $
 # installer for Twitter
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class TwitterInstaller(ExtensionInstaller):
     def __init__(self):
         super(TwitterInstaller, self).__init__(
-            version="0.7",
+            version="0.8",
             name='twitter',
             description='tweet weather data',
             author="Matthew Wall",
@@ -20,7 +20,7 @@ class TwitterInstaller(ExtensionInstaller):
                 'StdRESTful': {
                     'Twitter': {
                         'app_key': 'APP_KEY',
-                        'app_secret': 'APP_SECRET',
+                        'app_key_secret': 'APP_KEY_SECRET',
                         'oauth_token': 'OAUTH_TOKEN',
                         'oauth_token_secret': 'OAUTH_TOKEN_SECRET'}}},
             files=[('bin/user', ['bin/user/twitter.py'])]
